==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/services/logs/CfnMetricFilterProps.java <==
package software.amazon.awscdk.services.logs;

/**
 * Properties for defining a `AWS::Logs::MetricFilter`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:24:35.523Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_logs.CfnMetricFilterProps")
@software.amazon.jsii.Jsii.Proxy(CfnMetricFilterProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnMetricFilterProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Logs::MetricFilter.FilterPattern`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getFilterPattern();

    /**
     * `AWS::Logs::MetricFilter.LogGroupName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getLogGroupName();

    /**
     * `AWS::Logs::MetricFilter.MetricTransformations`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getMetricTransformations();

    /**
     * @return a {@link Builder} of {@link CfnMetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnMetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnMetricFilterProps> {
        private java.lang.String filterPattern;
        private java.lang.String logGroupName;
        private java.lang.Object metricTransformations;

        /**
         * Sets the value of {@link CfnMetricFilterProps#getFilterPattern}
         * @param filterPattern `AWS::Logs::MetricFilter.FilterPattern`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder filterPattern(java.lang.String filterPattern) {
            this.filterPattern = filterPattern;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricFilterProps#getLogGroupName}
         * @param logGroupName `AWS::Logs::MetricFilter.LogGroupName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logGroupName(java.lang.String logGroupName) {
            this.logGroupName = logGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricFilterProps#getMetricTransformations}
         * @param metricTransformations `AWS::Logs::MetricFilter.MetricTransformations`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricTransformations(software.amazon.awscdk.IResolvable metricTransformations) {
            this.metricTransformations = metricTransformations;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricFilterProps#getMetricTransformations}
         * @param metricTransformations `AWS::Logs::MetricFilter.MetricTransformations`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricTransformations(java.util.List<? extends java.lang.Object> metricTransformations) {
            this.metricTransformations = metricTransformations;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnMetricFilterProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnMetricFilterProps build() {
            return new Jsii$Proxy(filterPattern, logGroupName, metricTransformations);
        }
    }

    /**
     * An implementation for {@link CfnMetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnMetricFilterProps {
        private final java.lang.String filterPattern;
        private final java.lang.String logGroupName;
        private final java.lang.Object metricTransformations;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.filterPattern = software.amazon.jsii.Kernel.get(this, "filterPattern", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.logGroupName = software.amazon.jsii.Kernel.get(this, "logGroupName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.metricTransformations = software.amazon.jsii.Kernel.get(this, "metricTransformations", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String filterPattern, final java.lang.String logGroupName, final java.lang.Object metricTransformations) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.filterPattern = java.util.Objects.requireNonNull(filterPattern, "filterPattern is required");
            this.logGroupName = java.util.Objects.requireNonNull(logGroupName, "logGroupName is required");
            this.metricTransformations = java.util.Objects.requireNonNull(metricTransformations, "metricTransformations is required");
        }

        @Override
        public final java.lang.String getFilterPattern() {
            return this.filterPattern;
        }

        @Override
        public final java.lang.String getLogGroupName() {
            return this.logGroupName;
        }

        @Override
        public final java.lang.Object getMetricTransformations() {
            return this.metricTransformations;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("filterPattern", om.valueToTree(this.getFilterPattern()));
            data.set("logGroupName", om.valueToTree(this.getLogGroupName()));
            data.set("metricTransformations", om.valueToTree(this.getMetricTransformations()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_logs.CfnMetricFilterProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnMetricFilterProps.Jsii$Proxy that = (CfnMetricFilterProps.Jsii$Proxy) o;

            if (!filterPattern.equals(that.filterPattern)) return false;
            if (!logGroupName.equals(that.logGroupName)) return false;
            return this.metricTransformations.equals(that.metricTransformations);
        }

        @Override
        public final int hashCode() {
            int result = this.filterPattern.hashCode();
            result = 31 * result + (this.logGroupName.hashCode());
            result = 31 * result + (this.metricTransformations.hashCode());
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/logs/CfnMetricFilterProps.java <==
package software.amazon.awscdk.services.logs;

/**
 * Properties for defining a `CfnMetricFilter`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.logs.*;
 * CfnMetricFilterProps cfnMetricFilterProps = CfnMetricFilterProps.builder()
 *         .filterPattern("filterPattern")
 *         .logGroupName("logGroupName")
 *         .metricTransformations(List.of(MetricTransformationProperty.builder()
 *                 .metricName("metricName")
 *                 .metricNamespace("metricNamespace")
 *                 .metricValue("metricValue")
 *                 // the properties below are optional
 *                 .defaultValue(123)
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:11.459Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_logs.CfnMetricFilterProps")
@software.amazon.jsii.Jsii.Proxy(CfnMetricFilterProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnMetricFilterProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * A filter pattern for extracting metric data out of ingested log events.
     * <p>
     * For more information, see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html">Filter and Pattern Syntax</a> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getFilterPattern();

    /**
     * The name of an existing log group that you want to associate with this metric filter.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getLogGroupName();

    /**
     * The metric transformations.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getMetricTransformations();

    /**
     * @return a {@link Builder} of {@link CfnMetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnMetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnMetricFilterProps> {
        java.lang.String filterPattern;
        java.lang.String logGroupName;
        java.lang.Object metricTransformations;

        /**
         * Sets the value of {@link CfnMetricFilterProps#getFilterPattern}
         * @param filterPattern A filter pattern for extracting metric data out of ingested log events. This parameter is required.
         *                      For more information, see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html">Filter and Pattern Syntax</a> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder filterPattern(java.lang.String filterPattern) {
            this.filterPattern = filterPattern;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricFilterProps#getLogGroupName}
         * @param logGroupName The name of an existing log group that you want to associate with this metric filter. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logGroupName(java.lang.String logGroupName) {
            this.logGroupName = logGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricFilterProps#getMetricTransformations}
         * @param metricTransformations The metric transformations. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricTransformations(software.amazon.awscdk.IResolvable metricTransformations) {
            this.metricTransformations = metricTransformations;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricFilterProps#getMetricTransformations}
         * @param metricTransformations The metric transformations. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricTransformations(java.util.List<? extends java.lang.Object> metricTransformations) {
            this.metricTransformations = metricTransformations;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnMetricFilterProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnMetricFilterProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnMetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnMetricFilterProps {
        private final java.lang.String filterPattern;
        private final java.lang.String logGroupName;
        private final java.lang.Object metricTransformations;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.filterPattern = software.amazon.jsii.Kernel.get(this, "filterPattern", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.logGroupName = software.amazon.jsii.Kernel.get(this, "logGroupName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.metricTransformations = software.amazon.jsii.Kernel.get(this, "metricTransformations", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.filterPattern = java.util.Objects.requireNonNull(builder.filterPattern, "filterPattern is required");
            this.logGroupName = java.util.Objects.requireNonNull(builder.logGroupName, "logGroupName is required");
            this.metricTransformations = java.util.Objects.requireNonNull(builder.metricTransformations, "metricTransformations is required");
        }

        @Override
        public final java.lang.String getFilterPattern() {
            return this.filterPattern;
        }

        @Override
        public final java.lang.String getLogGroupName() {
            return this.logGroupName;
        }

        @Override
        public final java.lang.Object getMetricTransformations() {
            return this.metricTransformations;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("filterPattern", om.valueToTree(this.getFilterPattern()));
            data.set("logGroupName", om.valueToTree(this.getLogGroupName()));
            data.set("metricTransformations", om.valueToTree(this.getMetricTransformations()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_logs.CfnMetricFilterProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnMetricFilterProps.Jsii$Proxy that = (CfnMetricFilterProps.Jsii$Proxy) o;

            if (!filterPattern.equals(that.filterPattern)) return false;
            if (!logGroupName.equals(that.logGroupName)) return false;
            return this.metricTransformations.equals(that.metricTransformations);
        }

        @Override
        public final int hashCode() {
            int result = this.filterPattern.hashCode();
            result = 31 * result + (this.logGroupName.hashCode());
            result = 31 * result + (this.metricTransformations.hashCode());
            return result;
        }
    }
}
